/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 */

#include "sipAPIpictureflow.h"

#line 29 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/pictureflow.sip"
#include <pictureflow.h>
#line 12 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"

#line 28 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 16 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 254 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 19 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 283 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 22 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 754 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 25 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 213 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 28 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 254 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 31 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 33 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qimage.sip"
#include <qimage.h>
#line 34 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qfont.sip"
#include <qfont.h>
#line 37 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qsize.sip"
#include <qsize.h>
#line 40 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 11 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/pictureflow.sip"
#include <pictureflow.h>
#line 43 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 24 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 46 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qscreen.sip"
#include <qscreen.h>
#line 49 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 54 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qicon.sip"
#include <qicon.h>
#line 57 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qpainter.sip"
#include <qpainter.h>
#line 60 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 63 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 116 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qglobal.sip"
#include <QtGlobal>
#line 66 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qwindow.sip"
#include <qwindow.h>
#line 69 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 25 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qflags.sip"
#include <qglobal.h>
#line 72 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 75 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qrect.sip"
#include <qrect.h>
#line 78 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 25 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qflags.sip"
#include <qglobal.h>
#line 81 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qmargins.sip"
#include <qmargins.h>
#line 84 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 25 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qflags.sip"
#include <qglobal.h>
#line 87 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 90 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtWidgets/qgraphicsproxywidget.sip"
#include <qgraphicsproxywidget.h>
#line 93 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 145 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qglobal.sip"
#include <QtGlobal>
#line 96 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qlocale.sip"
#include <qlocale.h>
#line 99 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qfontinfo.sip"
#include <qfontinfo.h>
#line 102 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 105 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 108 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 380 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 111 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 114 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 117 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 339 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 120 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 325 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 123 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 444 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 126 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 497 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 129 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 466 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 132 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 483 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 135 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 555 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 138 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 807 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 141 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 353 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 144 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 297 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 147 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 269 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 150 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 742 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 153 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 239 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 156 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 788 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 159 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpoint.sip"
#include <qpoint.h>
#line 162 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 50 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 165 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 110 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpoint.sip"
#include <qpoint.h>
#line 168 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 135 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 171 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qaction.sip"
#include <qaction.h>
#line 174 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qkeysequence.sip"
#include <qkeysequence.h>
#line 177 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtWidgets/qlayout.sip"
#include <qlayout.h>
#line 180 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qregion.sip"
#include <qregion.h>
#line 183 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtWidgets/qsizepolicy.sip"
#include <qsizepolicy.h>
#line 186 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 25 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qflags.sip"
#include <qglobal.h>
#line 189 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qcursor.sip"
#include <qcursor.h>
#line 192 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qbitmap.sip"
#include <qbitmap.h>
#line 195 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qpalette.sip"
#include <qpalette.h>
#line 198 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtWidgets/qstyle.sip"
#include <qstyle.h>
#line 201 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 206 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 209 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 277 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 212 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 215 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 218 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 135 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 221 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 224 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 227 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 25 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qflags.sip"
#include <qglobal.h>
#line 230 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 233 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 236 "/build/calibre/src/calibre-9.11.0/build/pyqt/pictureflow/build/pictureflow/sippictureflowPictureFlow.cpp"


class sipPictureFlow : public ::PictureFlow
{
public:
    sipPictureFlow(::QWidget*, int);
    virtual ~sipPictureFlow();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::QImage slide(int) const SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    int metric(::QPaintDevice::PaintDeviceMetric) const SIP_OVERRIDE;
    ::QPaintEngine* paintEngine() const SIP_OVERRIDE;
    int devType() const SIP_OVERRIDE;
    void setVisible(bool) SIP_OVERRIDE;
    ::QSize sizeHint() const SIP_OVERRIDE;
    ::QSize minimumSizeHint() const SIP_OVERRIDE;
    int heightForWidth(int) const SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*) SIP_OVERRIDE;
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void enterEvent(::QEnterEvent*) SIP_OVERRIDE;
    void leaveEvent(::QEvent*) SIP_OVERRIDE;
    void paintEvent(::QPaintEvent*) SIP_OVERRIDE;
    void moveEvent(::QMoveEvent*) SIP_OVERRIDE;
    void resizeEvent(::QResizeEvent*) SIP_OVERRIDE;
    void closeEvent(::QCloseEvent*) SIP_OVERRIDE;
    void contextMenuEvent(::QContextMenuEvent*) SIP_OVERRIDE;
    void tabletEvent(::QTabletEvent*) SIP_OVERRIDE;
    void actionEvent(::QActionEvent*) SIP_OVERRIDE;
    void dragEnterEvent(::QDragEnterEvent*) SIP_OVERRIDE;
    void dragMoveEvent(::QDragMoveEvent*) SIP_OVERRIDE;
    void dragLeaveEvent(::QDragLeaveEvent*) SIP_OVERRIDE;
    void dropEvent(::QDropEvent*) SIP_OVERRIDE;
    void showEvent(::QShowEvent*) SIP_OVERRIDE;
    void hideEvent(::QHideEvent*) SIP_OVERRIDE;
    void changeEvent(::QEvent*) SIP_OVERRIDE;
    void inputMethodEvent(::QInputMethodEvent*) SIP_OVERRIDE;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery) const SIP_OVERRIDE;
    bool focusNextPrevChild(bool) SIP_OVERRIDE;
    bool hasHeightForWidth() const SIP_OVERRIDE;
    bool nativeEvent(const ::QByteArray&, void*, ::qintptr*) SIP_OVERRIDE;
    ::QPainter* sharedPainter() const SIP_OVERRIDE;
    void initPainter(::QPainter*) const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipPictureFlow(const sipPictureFlow &);
    sipPictureFlow &operator = (const sipPictureFlow &);

    char sipPyMethods[47];
};

sipPictureFlow::sipPictureFlow(::QWidget*a0, int a1): ::PictureFlow(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipPictureFlow::~sipPictureFlow()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipPictureFlow::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_pictureflow_qt_metaobject(sipPySelf, sipType_PictureFlow);

    return ::PictureFlow::metaObject();
}

int sipPictureFlow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::PictureFlow::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_pictureflow_qt_metacall(sipPySelf, sipType_PictureFlow, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipPictureFlow::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_pictureflow_qt_metacast(sipPySelf, sipType_PictureFlow, _clname, &sipCpp) ? sipCpp : ::PictureFlow::qt_metacast(_clname));
}

::QImage sipPictureFlow::slide(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_slide);

    if (!sipMeth)
        return ::PictureFlow::slide(a0);

    extern ::QImage sipVH_pictureflow_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_pictureflow_7(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipPictureFlow::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::PictureFlow::disconnectNotify(a0);
        return;
    }

    extern void sipVH_pictureflow_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_pictureflow_0(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipPictureFlow::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::PictureFlow::connectNotify(a0);
        return;
    }

    extern void sipVH_pictureflow_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_pictureflow_0(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipPictureFlow::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::PictureFlow::customEvent(a0);
        return;
    }

    extern void sipVH_pictureflow_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_pictureflow_1(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipPictureFlow::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::PictureFlow::childEvent(a0);
        return;
    }

    extern void sipVH_pictureflow_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_pictureflow_2(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipPictureFlow::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::PictureFlow::timerEvent(a0);
        return;
    }

    extern void sipVH_pictureflow_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_pictureflow_3(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipPictureFlow::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::PictureFlow::eventFilter(a0, a1);

    extern bool sipVH_pictureflow_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_pictureflow_4(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipPictureFlow::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::PictureFlow::event(a0);

    extern bool sipVH_pictureflow_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_pictureflow_5(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipPictureFlow::metric(::QPaintDevice::PaintDeviceMetric a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[8]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_metric);

    if (!sipMeth)
        return ::PictureFlow::metric(a0);

    extern int sipVH_pictureflow_38(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintDevice::PaintDeviceMetric);

    return sipVH_pictureflow_38(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPaintEngine* sipPictureFlow::paintEngine() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_paintEngine);

    if (!sipMeth)
        return ::PictureFlow::paintEngine();

    extern ::QPaintEngine* sipVH_pictureflow_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_pictureflow_37(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipPictureFlow::devType() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[10]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_devType);

    if (!sipMeth)
        return ::PictureFlow::devType();

    extern int sipVH_pictureflow_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_pictureflow_6(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipPictureFlow::setVisible(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_setVisible);

    if (!sipMeth)
    {
        ::PictureFlow::setVisible(a0);
        return;
    }

    extern void sipVH_pictureflow_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    sipVH_pictureflow_36(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QSize sipPictureFlow::sizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[12]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sizeHint);

    if (!sipMeth)
        return ::PictureFlow::sizeHint();

    extern ::QSize sipVH_pictureflow_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_pictureflow_35(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QSize sipPictureFlow::minimumSizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[13]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_minimumSizeHint);

    if (!sipMeth)
        return ::PictureFlow::minimumSizeHint();

    extern ::QSize sipVH_pictureflow_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_pictureflow_35(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipPictureFlow::heightForWidth(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[14]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_heightForWidth);

    if (!sipMeth)
        return ::PictureFlow::heightForWidth(a0);

    extern int sipVH_pictureflow_34(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_pictureflow_34(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipPictureFlow::mousePressEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_mousePressEvent);

    if (!sipMeth)
    {
        ::PictureFlow::mousePressEvent(a0);
        return;
    }

    extern void sipVH_pictureflow_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_pictureflow_33(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipPictureFlow::mouseReleaseEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_mouseReleaseEvent);

    if (!sipMeth)
    {
        ::PictureFlow::mouseReleaseEvent(a0);
        return;
    }

    extern void sipVH_pictureflow_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_pictureflow_33(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipPictureFlow::mouseDoubleClickEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_mouseDoubleClickEvent);

    if (!sipMeth)
    {
        ::PictureFlow::mouseDoubleClickEvent(a0);
        return;
    }

    extern void sipVH_pictureflow_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_pictureflow_33(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipPictureFlow::mouseMoveEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_mouseMoveEvent);

    if (!sipMeth)
    {
        ::PictureFlow::mouseMoveEvent(a0);
        return;
    }

    extern void sipVH_pictureflow_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_pictureflow_33(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipPictureFlow::wheelEvent(::QWheelEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[19], &sipPySelf, SIP_NULLPTR, sipName_wheelEvent);

    if (!sipMeth)
    {
        ::PictureFlow::wheelEvent(a0);
        return;
    }

    extern void sipVH_pictureflow_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWheelEvent*);

    sipVH_pictureflow_32(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipPictureFlow::keyPressEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[20], &sipPySelf, SIP_NULLPTR, sipName_keyPressEvent);

    if (!sipMeth)
    {
        ::PictureFlow::keyPressEvent(a0);
        return;
    }

    extern void sipVH_pictureflow_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_pictureflow_31(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipPictureFlow::keyReleaseEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[21], &sipPySelf, SIP_NULLPTR, sipName_keyReleaseEvent);

    if (!sipMeth)
    {
        ::PictureFlow::keyReleaseEvent(a0);
        return;
    }

    extern void sipVH_pictureflow_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_pictureflow_31(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipPictureFlow::focusInEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[22], &sipPySelf, SIP_NULLPTR, sipName_focusInEvent);

    if (!sipMeth)
    {
        ::PictureFlow::focusInEvent(a0);
        return;
    }

    extern void sipVH_pictureflow_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_pictureflow_30(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipPictureFlow::focusOutEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[23], &sipPySelf, SIP_NULLPTR, sipName_focusOutEvent);

    if (!sipMeth)
    {
        ::PictureFlow::focusOutEvent(a0);
        return;
    }

    extern void sipVH_pictureflow_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_pictureflow_30(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipPictureFlow::enterEvent(::QEnterEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[24], &sipPySelf, SIP_NULLPTR, sipName_enterEvent);

    if (!sipMeth)
    {
        ::PictureFlow::enterEvent(a0);
        return;
    }

    extern void sipVH_pictureflow_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEnterEvent*);

    sipVH_pictureflow_29(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipPictureFlow::leaveEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[25], &sipPySelf, SIP_NULLPTR, sipName_leaveEvent);

    if (!sipMeth)
    {
        ::PictureFlow::leaveEvent(a0);
        return;
    }

    extern void sipVH_pictureflow_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_pictureflow_1(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipPictureFlow::paintEvent(::QPaintEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[26], &sipPySelf, SIP_NULLPTR, sipName_paintEvent);

    if (!sipMeth)
    {
        ::PictureFlow::paintEvent(a0);
        return;
    }

    extern void sipVH_pictureflow_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintEvent*);

    sipVH_pictureflow_28(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipPictureFlow::moveEvent(::QMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[27], &sipPySelf, SIP_NULLPTR, sipName_moveEvent);

    if (!sipMeth)
    {
        ::PictureFlow::moveEvent(a0);
        return;
    }

    extern void sipVH_pictureflow_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMoveEvent*);

    sipVH_pictureflow_27(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipPictureFlow::resizeEvent(::QResizeEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[28], &sipPySelf, SIP_NULLPTR, sipName_resizeEvent);

    if (!sipMeth)
    {
        ::PictureFlow::resizeEvent(a0);
        return;
    }

    extern void sipVH_pictureflow_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QResizeEvent*);

    sipVH_pictureflow_26(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipPictureFlow::closeEvent(::QCloseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[29], &sipPySelf, SIP_NULLPTR, sipName_closeEvent);

    if (!sipMeth)
    {
        ::PictureFlow::closeEvent(a0);
        return;
    }

    extern void sipVH_pictureflow_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCloseEvent*);

    sipVH_pictureflow_25(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipPictureFlow::contextMenuEvent(::QContextMenuEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[30], &sipPySelf, SIP_NULLPTR, sipName_contextMenuEvent);

    if (!sipMeth)
    {
        ::PictureFlow::contextMenuEvent(a0);
        return;
    }

    extern void sipVH_pictureflow_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QContextMenuEvent*);

    sipVH_pictureflow_24(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipPictureFlow::tabletEvent(::QTabletEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[31], &sipPySelf, SIP_NULLPTR, sipName_tabletEvent);

    if (!sipMeth)
    {
        ::PictureFlow::tabletEvent(a0);
        return;
    }

    extern void sipVH_pictureflow_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTabletEvent*);

    sipVH_pictureflow_23(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipPictureFlow::actionEvent(::QActionEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[32], &sipPySelf, SIP_NULLPTR, sipName_actionEvent);

    if (!sipMeth)
    {
        ::PictureFlow::actionEvent(a0);
        return;
    }

    extern void sipVH_pictureflow_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QActionEvent*);

    sipVH_pictureflow_22(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipPictureFlow::dragEnterEvent(::QDragEnterEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[33], &sipPySelf, SIP_NULLPTR, sipName_dragEnterEvent);

    if (!sipMeth)
    {
        ::PictureFlow::dragEnterEvent(a0);
        return;
    }

    extern void sipVH_pictureflow_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragEnterEvent*);

    sipVH_pictureflow_21(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipPictureFlow::dragMoveEvent(::QDragMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[34], &sipPySelf, SIP_NULLPTR, sipName_dragMoveEvent);

    if (!sipMeth)
    {
        ::PictureFlow::dragMoveEvent(a0);
        return;
    }

    extern void sipVH_pictureflow_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragMoveEvent*);

    sipVH_pictureflow_20(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipPictureFlow::dragLeaveEvent(::QDragLeaveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[35], &sipPySelf, SIP_NULLPTR, sipName_dragLeaveEvent);

    if (!sipMeth)
    {
        ::PictureFlow::dragLeaveEvent(a0);
        return;
    }

    extern void sipVH_pictureflow_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragLeaveEvent*);

    sipVH_pictureflow_19(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipPictureFlow::dropEvent(::QDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[36], &sipPySelf, SIP_NULLPTR, sipName_dropEvent);

    if (!sipMeth)
    {
        ::PictureFlow::dropEvent(a0);
        return;
    }

    extern void sipVH_pictureflow_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDropEvent*);

    sipVH_pictureflow_18(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipPictureFlow::showEvent(::QShowEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[37], &sipPySelf, SIP_NULLPTR, sipName_showEvent);

    if (!sipMeth)
    {
        ::PictureFlow::showEvent(a0);
        return;
    }

    extern void sipVH_pictureflow_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QShowEvent*);

    sipVH_pictureflow_17(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipPictureFlow::hideEvent(::QHideEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[38], &sipPySelf, SIP_NULLPTR, sipName_hideEvent);

    if (!sipMeth)
    {
        ::PictureFlow::hideEvent(a0);
        return;
    }

    extern void sipVH_pictureflow_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QHideEvent*);

    sipVH_pictureflow_16(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipPictureFlow::changeEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[39], &sipPySelf, SIP_NULLPTR, sipName_changeEvent);

    if (!sipMeth)
    {
        ::PictureFlow::changeEvent(a0);
        return;
    }

    extern void sipVH_pictureflow_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_pictureflow_1(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipPictureFlow::inputMethodEvent(::QInputMethodEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[40], &sipPySelf, SIP_NULLPTR, sipName_inputMethodEvent);

    if (!sipMeth)
    {
        ::PictureFlow::inputMethodEvent(a0);
        return;
    }

    extern void sipVH_pictureflow_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QInputMethodEvent*);

    sipVH_pictureflow_15(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QVariant sipPictureFlow::inputMethodQuery(::Qt::InputMethodQuery a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[41]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_inputMethodQuery);

    if (!sipMeth)
        return ::PictureFlow::inputMethodQuery(a0);

    extern ::QVariant sipVH_pictureflow_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::Qt::InputMethodQuery);

    return sipVH_pictureflow_14(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipPictureFlow::focusNextPrevChild(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[42], &sipPySelf, SIP_NULLPTR, sipName_focusNextPrevChild);

    if (!sipMeth)
        return ::PictureFlow::focusNextPrevChild(a0);

    extern bool sipVH_pictureflow_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    return sipVH_pictureflow_13(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipPictureFlow::hasHeightForWidth() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[43]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_hasHeightForWidth);

    if (!sipMeth)
        return ::PictureFlow::hasHeightForWidth();

    extern bool sipVH_pictureflow_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_pictureflow_12(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipPictureFlow::nativeEvent(const ::QByteArray& a0, void*a1, ::qintptr*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[44], &sipPySelf, SIP_NULLPTR, sipName_nativeEvent);

    if (!sipMeth)
        return ::PictureFlow::nativeEvent(a0, a1, a2);

    extern bool sipVH_pictureflow_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QByteArray&, void*, ::qintptr*);

    return sipVH_pictureflow_11(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

::QPainter* sipPictureFlow::sharedPainter() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[45]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sharedPainter);

    if (!sipMeth)
        return ::PictureFlow::sharedPainter();

    extern ::QPainter* sipVH_pictureflow_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_pictureflow_10(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipPictureFlow::initPainter(::QPainter*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[46]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_initPainter);

    if (!sipMeth)
    {
        ::PictureFlow::initPainter(a0);
        return;
    }

    extern void sipVH_pictureflow_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*);

    sipVH_pictureflow_9(sipGILState, sipImportedVirtErrorHandlers_pictureflow_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_PictureFlow_setImages, "setImages(self, images: FlowImages|None)");

extern "C" {static PyObject *meth_PictureFlow_setImages(PyObject *, PyObject *);}
static PyObject *meth_PictureFlow_setImages(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::FlowImages* a0;
        ::PictureFlow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_PictureFlow, &sipCpp, sipType_FlowImages, &a0))
        {
            sipCpp->setImages(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_PictureFlow, sipName_setImages, doc_PictureFlow_setImages);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_PictureFlow_count, "count(self) -> int");

extern "C" {static PyObject *meth_PictureFlow_count(PyObject *, PyObject *);}
static PyObject *meth_PictureFlow_count(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::PictureFlow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_PictureFlow, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->count();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_PictureFlow, sipName_count, doc_PictureFlow_count);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_PictureFlow_slideSize, "slideSize(self) -> QSize");

extern "C" {static PyObject *meth_PictureFlow_slideSize(PyObject *, PyObject *);}
static PyObject *meth_PictureFlow_slideSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::PictureFlow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_PictureFlow, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize(sipCpp->slideSize());

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_PictureFlow, sipName_slideSize, doc_PictureFlow_slideSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_PictureFlow_setSlideSize, "setSlideSize(self, size: QSize)");

extern "C" {static PyObject *meth_PictureFlow_setSlideSize(PyObject *, PyObject *);}
static PyObject *meth_PictureFlow_setSlideSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QSize* a0;
        ::PictureFlow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_PictureFlow, &sipCpp, sipType_QSize, &a0))
        {
            sipCpp->setSlideSize(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_PictureFlow, sipName_setSlideSize, doc_PictureFlow_setSlideSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_PictureFlow_activateOnDoubleClick, "activateOnDoubleClick(self) -> bool");

extern "C" {static PyObject *meth_PictureFlow_activateOnDoubleClick(PyObject *, PyObject *);}
static PyObject *meth_PictureFlow_activateOnDoubleClick(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::PictureFlow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_PictureFlow, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->activateOnDoubleClick();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_PictureFlow, sipName_activateOnDoubleClick, doc_PictureFlow_activateOnDoubleClick);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_PictureFlow_setActivateOnDoubleClick, "setActivateOnDoubleClick(self, on: bool)");

extern "C" {static PyObject *meth_PictureFlow_setActivateOnDoubleClick(PyObject *, PyObject *);}
static PyObject *meth_PictureFlow_setActivateOnDoubleClick(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::PictureFlow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_PictureFlow, &sipCpp, &a0))
        {
            sipCpp->setActivateOnDoubleClick(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_PictureFlow, sipName_setActivateOnDoubleClick, doc_PictureFlow_setActivateOnDoubleClick);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_PictureFlow_preserveAspectRatio, "preserveAspectRatio(self) -> bool");

extern "C" {static PyObject *meth_PictureFlow_preserveAspectRatio(PyObject *, PyObject *);}
static PyObject *meth_PictureFlow_preserveAspectRatio(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::PictureFlow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_PictureFlow, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->preserveAspectRatio();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_PictureFlow, sipName_preserveAspectRatio, doc_PictureFlow_preserveAspectRatio);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_PictureFlow_setPreserveAspectRatio, "setPreserveAspectRatio(self, preserve: bool)");

extern "C" {static PyObject *meth_PictureFlow_setPreserveAspectRatio(PyObject *, PyObject *);}
static PyObject *meth_PictureFlow_setPreserveAspectRatio(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::PictureFlow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_PictureFlow, &sipCpp, &a0))
        {
            sipCpp->setPreserveAspectRatio(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_PictureFlow, sipName_setPreserveAspectRatio, doc_PictureFlow_setPreserveAspectRatio);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_PictureFlow_subtitleFont, "subtitleFont(self) -> QFont");

extern "C" {static PyObject *meth_PictureFlow_subtitleFont(PyObject *, PyObject *);}
static PyObject *meth_PictureFlow_subtitleFont(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::PictureFlow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_PictureFlow, &sipCpp))
        {
            ::QFont*sipRes;

            sipRes = new ::QFont(sipCpp->subtitleFont());

            return sipConvertFromNewType(sipRes, sipType_QFont, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_PictureFlow, sipName_subtitleFont, doc_PictureFlow_subtitleFont);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_PictureFlow_setSubtitleFont, "setSubtitleFont(self, font: QFont)");

extern "C" {static PyObject *meth_PictureFlow_setSubtitleFont(PyObject *, PyObject *);}
static PyObject *meth_PictureFlow_setSubtitleFont(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QFont* a0;
        ::PictureFlow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_PictureFlow, &sipCpp, sipType_QFont, &a0))
        {
            sipCpp->setSubtitleFont(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_PictureFlow, sipName_setSubtitleFont, doc_PictureFlow_setSubtitleFont);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_PictureFlow_clearCaches, "clearCaches(self)");

extern "C" {static PyObject *meth_PictureFlow_clearCaches(PyObject *, PyObject *);}
static PyObject *meth_PictureFlow_clearCaches(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::PictureFlow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_PictureFlow, &sipCpp))
        {
            sipCpp->clearCaches();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_PictureFlow, sipName_clearCaches, doc_PictureFlow_clearCaches);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_PictureFlow_slide, "slide(self, index: int) -> QImage");

extern "C" {static PyObject *meth_PictureFlow_slide(PyObject *, PyObject *);}
static PyObject *meth_PictureFlow_slide(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_PictureFlow)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        const ::PictureFlow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_PictureFlow, &sipCpp, &a0))
        {
            ::QImage*sipRes;

            sipRes = new ::QImage((sipSelfWasArg ? sipCpp->::PictureFlow::slide(a0) : sipCpp->slide(a0)));

            return sipConvertFromNewType(sipRes, sipType_QImage, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_PictureFlow, sipName_slide, doc_PictureFlow_slide);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_PictureFlow_currentSlide, "currentSlide(self) -> int");

extern "C" {static PyObject *meth_PictureFlow_currentSlide(PyObject *, PyObject *);}
static PyObject *meth_PictureFlow_currentSlide(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::PictureFlow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_PictureFlow, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->currentSlide();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_PictureFlow, sipName_currentSlide, doc_PictureFlow_currentSlide);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_PictureFlow_showReflections, "showReflections(self) -> bool");

extern "C" {static PyObject *meth_PictureFlow_showReflections(PyObject *, PyObject *);}
static PyObject *meth_PictureFlow_showReflections(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::PictureFlow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_PictureFlow, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->showReflections();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_PictureFlow, sipName_showReflections, doc_PictureFlow_showReflections);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_PictureFlow_setShowReflections, "setShowReflections(self, show: bool)");

extern "C" {static PyObject *meth_PictureFlow_setShowReflections(PyObject *, PyObject *);}
static PyObject *meth_PictureFlow_setShowReflections(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::PictureFlow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_PictureFlow, &sipCpp, &a0))
        {
            sipCpp->setShowReflections(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_PictureFlow, sipName_setShowReflections, doc_PictureFlow_setShowReflections);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_PictureFlow_maxFontSize, "maxFontSize(self) -> int");

extern "C" {static PyObject *meth_PictureFlow_maxFontSize(PyObject *, PyObject *);}
static PyObject *meth_PictureFlow_maxFontSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::PictureFlow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_PictureFlow, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maxFontSize();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_PictureFlow, sipName_maxFontSize, doc_PictureFlow_maxFontSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_PictureFlow_setMaxFontSize, "setMaxFontSize(self, val: int)");

extern "C" {static PyObject *meth_PictureFlow_setMaxFontSize(PyObject *, PyObject *);}
static PyObject *meth_PictureFlow_setMaxFontSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::PictureFlow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_PictureFlow, &sipCpp, &a0))
        {
            sipCpp->setMaxFontSize(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_PictureFlow, sipName_setMaxFontSize, doc_PictureFlow_setMaxFontSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_PictureFlow_setCurrentSlide, "setCurrentSlide(self, index: int)");

extern "C" {static PyObject *meth_PictureFlow_setCurrentSlide(PyObject *, PyObject *);}
static PyObject *meth_PictureFlow_setCurrentSlide(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::PictureFlow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_PictureFlow, &sipCpp, &a0))
        {
            sipCpp->setCurrentSlide(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_PictureFlow, sipName_setCurrentSlide, doc_PictureFlow_setCurrentSlide);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_PictureFlow_render, "render(self)");

extern "C" {static PyObject *meth_PictureFlow_render(PyObject *, PyObject *);}
static PyObject *meth_PictureFlow_render(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::PictureFlow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_PictureFlow, &sipCpp))
        {
            sipCpp->render();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_PictureFlow, sipName_render, doc_PictureFlow_render);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_PictureFlow_showPrevious, "showPrevious(self)");

extern "C" {static PyObject *meth_PictureFlow_showPrevious(PyObject *, PyObject *);}
static PyObject *meth_PictureFlow_showPrevious(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::PictureFlow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_PictureFlow, &sipCpp))
        {
            sipCpp->showPrevious();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_PictureFlow, sipName_showPrevious, doc_PictureFlow_showPrevious);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_PictureFlow_showNext, "showNext(self)");

extern "C" {static PyObject *meth_PictureFlow_showNext(PyObject *, PyObject *);}
static PyObject *meth_PictureFlow_showNext(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::PictureFlow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_PictureFlow, &sipCpp))
        {
            sipCpp->showNext();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_PictureFlow, sipName_showNext, doc_PictureFlow_showNext);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_PictureFlow_showSlide, "showSlide(self, index: int)");

extern "C" {static PyObject *meth_PictureFlow_showSlide(PyObject *, PyObject *);}
static PyObject *meth_PictureFlow_showSlide(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::PictureFlow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_PictureFlow, &sipCpp, &a0))
        {
            sipCpp->showSlide(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_PictureFlow, sipName_showSlide, doc_PictureFlow_showSlide);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_PictureFlow_dataChanged, "dataChanged(self)");

extern "C" {static PyObject *meth_PictureFlow_dataChanged(PyObject *, PyObject *);}
static PyObject *meth_PictureFlow_dataChanged(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::PictureFlow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_PictureFlow, &sipCpp))
        {
            sipCpp->dataChanged();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_PictureFlow, sipName_dataChanged, doc_PictureFlow_dataChanged);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_PictureFlow_paintEvent, "paintEvent(self, event: QPaintEvent|None)");

extern "C" {static PyObject *meth_PictureFlow_paintEvent(PyObject *, PyObject *);}
static PyObject *meth_PictureFlow_paintEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_PictureFlow)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QPaintEvent* a0;
        ::PictureFlow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_PictureFlow, &sipCpp, sipType_QPaintEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::PictureFlow::paintEvent(a0) : sipCpp->paintEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_PictureFlow, sipName_paintEvent, doc_PictureFlow_paintEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_PictureFlow_keyPressEvent, "keyPressEvent(self, event: QKeyEvent|None)");

extern "C" {static PyObject *meth_PictureFlow_keyPressEvent(PyObject *, PyObject *);}
static PyObject *meth_PictureFlow_keyPressEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_PictureFlow)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QKeyEvent* a0;
        ::PictureFlow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_PictureFlow, &sipCpp, sipType_QKeyEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::PictureFlow::keyPressEvent(a0) : sipCpp->keyPressEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_PictureFlow, sipName_keyPressEvent, doc_PictureFlow_keyPressEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_PictureFlow_mouseMoveEvent, "mouseMoveEvent(self, event: QMouseEvent|None)");

extern "C" {static PyObject *meth_PictureFlow_mouseMoveEvent(PyObject *, PyObject *);}
static PyObject *meth_PictureFlow_mouseMoveEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_PictureFlow)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMouseEvent* a0;
        ::PictureFlow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_PictureFlow, &sipCpp, sipType_QMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::PictureFlow::mouseMoveEvent(a0) : sipCpp->mouseMoveEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_PictureFlow, sipName_mouseMoveEvent, doc_PictureFlow_mouseMoveEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_PictureFlow_mousePressEvent, "mousePressEvent(self, event: QMouseEvent|None)");

extern "C" {static PyObject *meth_PictureFlow_mousePressEvent(PyObject *, PyObject *);}
static PyObject *meth_PictureFlow_mousePressEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_PictureFlow)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMouseEvent* a0;
        ::PictureFlow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_PictureFlow, &sipCpp, sipType_QMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::PictureFlow::mousePressEvent(a0) : sipCpp->mousePressEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_PictureFlow, sipName_mousePressEvent, doc_PictureFlow_mousePressEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_PictureFlow_mouseReleaseEvent, "mouseReleaseEvent(self, event: QMouseEvent|None)");

extern "C" {static PyObject *meth_PictureFlow_mouseReleaseEvent(PyObject *, PyObject *);}
static PyObject *meth_PictureFlow_mouseReleaseEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_PictureFlow)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMouseEvent* a0;
        ::PictureFlow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_PictureFlow, &sipCpp, sipType_QMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::PictureFlow::mouseReleaseEvent(a0) : sipCpp->mouseReleaseEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_PictureFlow, sipName_mouseReleaseEvent, doc_PictureFlow_mouseReleaseEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_PictureFlow_resizeEvent, "resizeEvent(self, event: QResizeEvent|None)");

extern "C" {static PyObject *meth_PictureFlow_resizeEvent(PyObject *, PyObject *);}
static PyObject *meth_PictureFlow_resizeEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_PictureFlow)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QResizeEvent* a0;
        ::PictureFlow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_PictureFlow, &sipCpp, sipType_QResizeEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::PictureFlow::resizeEvent(a0) : sipCpp->resizeEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_PictureFlow, sipName_resizeEvent, doc_PictureFlow_resizeEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_PictureFlow_timerEvent, "timerEvent(self, event: QTimerEvent|None)");

extern "C" {static PyObject *meth_PictureFlow_timerEvent(PyObject *, PyObject *);}
static PyObject *meth_PictureFlow_timerEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_PictureFlow)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QTimerEvent* a0;
        ::PictureFlow *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_PictureFlow, &sipCpp, sipType_QTimerEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::PictureFlow::timerEvent(a0) : sipCpp->timerEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_PictureFlow, sipName_timerEvent, doc_PictureFlow_timerEvent);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_PictureFlow(void *, const sipTypeDef *);}
static void *cast_PictureFlow(void *sipCppV, const sipTypeDef *targetType)
{
    ::PictureFlow *sipCpp = reinterpret_cast< ::PictureFlow *>(sipCppV);

    if (targetType == sipType_PictureFlow)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QWidget)->ctd_cast(static_cast< ::QWidget *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_PictureFlow(void *, int);}
static void release_PictureFlow(void *sipCppV, int)
{
    ::PictureFlow *sipCpp = reinterpret_cast< ::PictureFlow *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_PictureFlow(Py_ssize_t);}
static void *array_PictureFlow(Py_ssize_t sipNrElem)
{
    return new ::PictureFlow[sipNrElem];
}


extern "C" {static void array_delete_PictureFlow(void *);}
static void array_delete_PictureFlow(void *sipCpp)
{
    delete[] reinterpret_cast< ::PictureFlow *>(sipCpp);
}


extern "C" {static void dealloc_PictureFlow(sipSimpleWrapper *);}
static void dealloc_PictureFlow(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipPictureFlow *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_PictureFlow(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_PictureFlow(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_PictureFlow(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipPictureFlow *sipCpp = SIP_NULLPTR;

    {
        ::QWidget* a0 = 0;
        int a1 = 3;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "|JHi", sipType_QWidget, &a0, sipOwner, &a1))
        {
            sipCpp = new sipPictureFlow(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_PictureFlow[] = {{0, 2, 1}};


static PyMethodDef methods_PictureFlow[] = {
    {sipName_activateOnDoubleClick, meth_PictureFlow_activateOnDoubleClick, METH_VARARGS, doc_PictureFlow_activateOnDoubleClick},
    {sipName_clearCaches, meth_PictureFlow_clearCaches, METH_VARARGS, doc_PictureFlow_clearCaches},
    {sipName_count, meth_PictureFlow_count, METH_VARARGS, doc_PictureFlow_count},
    {sipName_currentSlide, meth_PictureFlow_currentSlide, METH_VARARGS, doc_PictureFlow_currentSlide},
    {sipName_dataChanged, meth_PictureFlow_dataChanged, METH_VARARGS, doc_PictureFlow_dataChanged},
    {sipName_keyPressEvent, meth_PictureFlow_keyPressEvent, METH_VARARGS, doc_PictureFlow_keyPressEvent},
    {sipName_maxFontSize, meth_PictureFlow_maxFontSize, METH_VARARGS, doc_PictureFlow_maxFontSize},
    {sipName_mouseMoveEvent, meth_PictureFlow_mouseMoveEvent, METH_VARARGS, doc_PictureFlow_mouseMoveEvent},
    {sipName_mousePressEvent, meth_PictureFlow_mousePressEvent, METH_VARARGS, doc_PictureFlow_mousePressEvent},
    {sipName_mouseReleaseEvent, meth_PictureFlow_mouseReleaseEvent, METH_VARARGS, doc_PictureFlow_mouseReleaseEvent},
    {sipName_paintEvent, meth_PictureFlow_paintEvent, METH_VARARGS, doc_PictureFlow_paintEvent},
    {sipName_preserveAspectRatio, meth_PictureFlow_preserveAspectRatio, METH_VARARGS, doc_PictureFlow_preserveAspectRatio},
    {sipName_render, meth_PictureFlow_render, METH_VARARGS, doc_PictureFlow_render},
    {sipName_resizeEvent, meth_PictureFlow_resizeEvent, METH_VARARGS, doc_PictureFlow_resizeEvent},
    {sipName_setActivateOnDoubleClick, meth_PictureFlow_setActivateOnDoubleClick, METH_VARARGS, doc_PictureFlow_setActivateOnDoubleClick},
    {sipName_setCurrentSlide, meth_PictureFlow_setCurrentSlide, METH_VARARGS, doc_PictureFlow_setCurrentSlide},
    {sipName_setImages, meth_PictureFlow_setImages, METH_VARARGS, doc_PictureFlow_setImages},
    {sipName_setMaxFontSize, meth_PictureFlow_setMaxFontSize, METH_VARARGS, doc_PictureFlow_setMaxFontSize},
    {sipName_setPreserveAspectRatio, meth_PictureFlow_setPreserveAspectRatio, METH_VARARGS, doc_PictureFlow_setPreserveAspectRatio},
    {sipName_setShowReflections, meth_PictureFlow_setShowReflections, METH_VARARGS, doc_PictureFlow_setShowReflections},
    {sipName_setSlideSize, meth_PictureFlow_setSlideSize, METH_VARARGS, doc_PictureFlow_setSlideSize},
    {sipName_setSubtitleFont, meth_PictureFlow_setSubtitleFont, METH_VARARGS, doc_PictureFlow_setSubtitleFont},
    {sipName_showNext, meth_PictureFlow_showNext, METH_VARARGS, doc_PictureFlow_showNext},
    {sipName_showPrevious, meth_PictureFlow_showPrevious, METH_VARARGS, doc_PictureFlow_showPrevious},
    {sipName_showReflections, meth_PictureFlow_showReflections, METH_VARARGS, doc_PictureFlow_showReflections},
    {sipName_showSlide, meth_PictureFlow_showSlide, METH_VARARGS, doc_PictureFlow_showSlide},
    {sipName_slide, meth_PictureFlow_slide, METH_VARARGS, doc_PictureFlow_slide},
    {sipName_slideSize, meth_PictureFlow_slideSize, METH_VARARGS, doc_PictureFlow_slideSize},
    {sipName_subtitleFont, meth_PictureFlow_subtitleFont, METH_VARARGS, doc_PictureFlow_subtitleFont},
    {sipName_timerEvent, meth_PictureFlow_timerEvent, METH_VARARGS, doc_PictureFlow_timerEvent}
};

PyDoc_STRVAR(doc_PictureFlow, "\1PictureFlow(parent: QWidget|None = None, queueLength: int = 3)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_PictureFlow[] = {
    {"stop()", "\1stop(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"currentChanged(int)", "\1currentChanged(self, index: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"itemActivated(int)", "\1itemActivated(self, index: int)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_PictureFlow = {
    &::PictureFlow::staticMetaObject,
    signals_PictureFlow,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_pictureflow_PictureFlow = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_CLASS,
        sipNameNr_PictureFlow,
        SIP_NULLPTR,
        &plugin_PictureFlow,
    },
    {
        sipNameNr_PictureFlow,
        {0, 0, 1},
        30, methods_PictureFlow,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_PictureFlow,
    -1,
    -1,
    supers_PictureFlow,
    SIP_NULLPTR,
    init_type_PictureFlow,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_PictureFlow,
    SIP_NULLPTR,
    array_PictureFlow,
    SIP_NULLPTR,
    release_PictureFlow,
    cast_PictureFlow,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_PictureFlow,
    sizeof (::PictureFlow),
};
