/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 */

#include "sipAPIprogress_indicator.h"

#line 16 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/QProgressIndicator.sip"
#include <QProgressIndicator.h>
#line 12 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"

#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 16 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 19 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtWidgets/qapplication.sip"
#include <qapplication.h>
#line 22 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qpalette.sip"
#include <qpalette.h>
#line 25 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 28 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qicon.sip"
#include <qicon.h>
#line 31 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 34 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtWidgets/qstyle.sip"
#include <qstyle.h>
#line 37 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtWidgets/qsizepolicy.sip"
#include <qsizepolicy.h>
#line 40 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 45 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 923 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 48 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 749 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 51 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpoint.sip"
#include <qpoint.h>
#line 54 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qrect.sip"
#include <qrect.h>
#line 57 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 60 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 24 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 63 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qsize.sip"
#include <qsize.h>
#line 66 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qpainter.sip"
#include <qpainter.h>
#line 69 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 25 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qflags.sip"
#include <qglobal.h>
#line 72 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 25 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qflags.sip"
#include <qglobal.h>
#line 75 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 80 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 83 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 277 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 86 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 254 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 89 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 92 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 95 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 98 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 101 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 135 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 104 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 107 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 110 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 25 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qflags.sip"
#include <qglobal.h>
#line 113 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 116 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 119 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorCalibreStyle.cpp"


class sipCalibreStyle : public ::CalibreStyle
{
public:
    sipCalibreStyle(int);
    virtual ~sipCalibreStyle();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    void polish(::QWidget*) SIP_OVERRIDE;
    void unpolish(::QWidget*) SIP_OVERRIDE;
    void polish(::QApplication*) SIP_OVERRIDE;
    void unpolish(::QApplication*) SIP_OVERRIDE;
    void polish(::QPalette&) SIP_OVERRIDE;
    ::QRect itemTextRect(const ::QFontMetrics&, const ::QRect&, int, bool, const ::QString&) const SIP_OVERRIDE;
    ::QRect itemPixmapRect(const ::QRect&, int, const ::QPixmap&) const SIP_OVERRIDE;
    void drawItemText(::QPainter*, const ::QRect&, int, const ::QPalette&, bool, const ::QString&, ::QPalette::ColorRole) const SIP_OVERRIDE;
    void drawItemPixmap(::QPainter*, const ::QRect&, int, const ::QPixmap&) const SIP_OVERRIDE;
    ::QPalette standardPalette() const SIP_OVERRIDE;
    void drawPrimitive(::QStyle::PrimitiveElement, const ::QStyleOption*, ::QPainter*, const ::QWidget*) const SIP_OVERRIDE;
    void drawControl(::QStyle::ControlElement, const ::QStyleOption*, ::QPainter*, const ::QWidget*) const SIP_OVERRIDE;
    ::QRect subElementRect(::QStyle::SubElement, const ::QStyleOption*, const ::QWidget*) const SIP_OVERRIDE;
    void drawComplexControl(::QStyle::ComplexControl, const ::QStyleOptionComplex*, ::QPainter*, const ::QWidget*) const SIP_OVERRIDE;
    ::QStyle::SubControl hitTestComplexControl(::QStyle::ComplexControl, const ::QStyleOptionComplex*, const ::QPoint&, const ::QWidget*) const SIP_OVERRIDE;
    ::QRect subControlRect(::QStyle::ComplexControl, const ::QStyleOptionComplex*, ::QStyle::SubControl, const ::QWidget*) const SIP_OVERRIDE;
    int pixelMetric(::QStyle::PixelMetric, const ::QStyleOption*, const ::QWidget*) const SIP_OVERRIDE;
    ::QSize sizeFromContents(::QStyle::ContentsType, const ::QStyleOption*, const ::QSize&, const ::QWidget*) const SIP_OVERRIDE;
    int styleHint(::QStyle::StyleHint, const ::QStyleOption*, const ::QWidget*, ::QStyleHintReturn*) const SIP_OVERRIDE;
    ::QPixmap standardPixmap(::QStyle::StandardPixmap, const ::QStyleOption*, const ::QWidget*) const SIP_OVERRIDE;
    ::QIcon standardIcon(::QStyle::StandardPixmap, const ::QStyleOption*, const ::QWidget*) const SIP_OVERRIDE;
    ::QPixmap generatedIconPixmap(::QIcon::Mode, const ::QPixmap&, const ::QStyleOption*) const SIP_OVERRIDE;
    int layoutSpacing(::QSizePolicy::ControlType, ::QSizePolicy::ControlType, ::Qt::Orientation, const ::QStyleOption*, const ::QWidget*) const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipCalibreStyle(const sipCalibreStyle &);
    sipCalibreStyle &operator = (const sipCalibreStyle &);

    char sipPyMethods[30];
};

sipCalibreStyle::sipCalibreStyle(int a0): ::CalibreStyle(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipCalibreStyle::~sipCalibreStyle()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipCalibreStyle::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_progress_indicator_qt_metaobject(sipPySelf, sipType_CalibreStyle);

    return ::CalibreStyle::metaObject();
}

int sipCalibreStyle::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::CalibreStyle::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_progress_indicator_qt_metacall(sipPySelf, sipType_CalibreStyle, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipCalibreStyle::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_progress_indicator_qt_metacast(sipPySelf, sipType_CalibreStyle, _clname, &sipCpp) ? sipCpp : ::CalibreStyle::qt_metacast(_clname));
}

void sipCalibreStyle::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::CalibreStyle::disconnectNotify(a0);
        return;
    }

    extern void sipVH_progress_indicator_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_progress_indicator_26(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipCalibreStyle::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::CalibreStyle::connectNotify(a0);
        return;
    }

    extern void sipVH_progress_indicator_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_progress_indicator_26(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipCalibreStyle::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::CalibreStyle::customEvent(a0);
        return;
    }

    extern void sipVH_progress_indicator_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_progress_indicator_25(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipCalibreStyle::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::CalibreStyle::childEvent(a0);
        return;
    }

    extern void sipVH_progress_indicator_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_progress_indicator_24(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipCalibreStyle::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::CalibreStyle::timerEvent(a0);
        return;
    }

    extern void sipVH_progress_indicator_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_progress_indicator_23(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipCalibreStyle::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::CalibreStyle::eventFilter(a0, a1);

    extern bool sipVH_progress_indicator_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_progress_indicator_22(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipCalibreStyle::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::CalibreStyle::event(a0);

    extern bool sipVH_progress_indicator_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_progress_indicator_21(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipCalibreStyle::polish(::QWidget*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_polish);

    if (!sipMeth)
    {
        ::CalibreStyle::polish(a0);
        return;
    }

    extern void sipVH_progress_indicator_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWidget*);

    sipVH_progress_indicator_20(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipCalibreStyle::unpolish(::QWidget*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_unpolish);

    if (!sipMeth)
    {
        ::CalibreStyle::unpolish(a0);
        return;
    }

    extern void sipVH_progress_indicator_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWidget*);

    sipVH_progress_indicator_20(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipCalibreStyle::polish(::QApplication*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_polish);

    if (!sipMeth)
    {
        ::CalibreStyle::polish(a0);
        return;
    }

    extern void sipVH_progress_indicator_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QApplication*);

    sipVH_progress_indicator_19(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipCalibreStyle::unpolish(::QApplication*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_unpolish);

    if (!sipMeth)
    {
        ::CalibreStyle::unpolish(a0);
        return;
    }

    extern void sipVH_progress_indicator_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QApplication*);

    sipVH_progress_indicator_19(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipCalibreStyle::polish(::QPalette& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_polish);

    if (!sipMeth)
    {
        ::CalibreStyle::polish(a0);
        return;
    }

    extern void sipVH_progress_indicator_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPalette&);

    sipVH_progress_indicator_18(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QRect sipCalibreStyle::itemTextRect(const ::QFontMetrics& a0, const ::QRect& a1, int a2, bool a3, const ::QString& a4) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[12]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_itemTextRect);

    if (!sipMeth)
        return ::CalibreStyle::itemTextRect(a0, a1, a2, a3, a4);

    extern ::QRect sipVH_progress_indicator_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QFontMetrics&, const ::QRect&, int, bool, const ::QString&);

    return sipVH_progress_indicator_17(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3, a4);
}

::QRect sipCalibreStyle::itemPixmapRect(const ::QRect& a0, int a1, const ::QPixmap& a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[13]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_itemPixmapRect);

    if (!sipMeth)
        return ::CalibreStyle::itemPixmapRect(a0, a1, a2);

    extern ::QRect sipVH_progress_indicator_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QRect&, int, const ::QPixmap&);

    return sipVH_progress_indicator_16(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

void sipCalibreStyle::drawItemText(::QPainter*a0, const ::QRect& a1, int a2, const ::QPalette& a3, bool a4, const ::QString& a5, ::QPalette::ColorRole a6) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[14]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_drawItemText);

    if (!sipMeth)
    {
        ::CalibreStyle::drawItemText(a0, a1, a2, a3, a4, a5, a6);
        return;
    }

    extern void sipVH_progress_indicator_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*, const ::QRect&, int, const ::QPalette&, bool, const ::QString&, ::QPalette::ColorRole);

    sipVH_progress_indicator_15(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3, a4, a5, a6);
}

void sipCalibreStyle::drawItemPixmap(::QPainter*a0, const ::QRect& a1, int a2, const ::QPixmap& a3) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[15]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_drawItemPixmap);

    if (!sipMeth)
    {
        ::CalibreStyle::drawItemPixmap(a0, a1, a2, a3);
        return;
    }

    extern void sipVH_progress_indicator_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*, const ::QRect&, int, const ::QPixmap&);

    sipVH_progress_indicator_14(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

::QPalette sipCalibreStyle::standardPalette() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[16]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_standardPalette);

    if (!sipMeth)
        return ::CalibreStyle::standardPalette();

    extern ::QPalette sipVH_progress_indicator_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_progress_indicator_13(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipCalibreStyle::drawPrimitive(::QStyle::PrimitiveElement a0, const ::QStyleOption*a1, ::QPainter*a2, const ::QWidget*a3) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[17]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_drawPrimitive);

    if (!sipMeth)
    {
        ::CalibreStyle::drawPrimitive(a0, a1, a2, a3);
        return;
    }

    extern void sipVH_progress_indicator_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QStyle::PrimitiveElement, const ::QStyleOption*, ::QPainter*, const ::QWidget*);

    sipVH_progress_indicator_12(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

void sipCalibreStyle::drawControl(::QStyle::ControlElement a0, const ::QStyleOption*a1, ::QPainter*a2, const ::QWidget*a3) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[18]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_drawControl);

    if (!sipMeth)
    {
        ::CalibreStyle::drawControl(a0, a1, a2, a3);
        return;
    }

    extern void sipVH_progress_indicator_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QStyle::ControlElement, const ::QStyleOption*, ::QPainter*, const ::QWidget*);

    sipVH_progress_indicator_11(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

::QRect sipCalibreStyle::subElementRect(::QStyle::SubElement a0, const ::QStyleOption*a1, const ::QWidget*a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[19]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_subElementRect);

    if (!sipMeth)
        return ::CalibreStyle::subElementRect(a0, a1, a2);

    extern ::QRect sipVH_progress_indicator_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QStyle::SubElement, const ::QStyleOption*, const ::QWidget*);

    return sipVH_progress_indicator_10(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

void sipCalibreStyle::drawComplexControl(::QStyle::ComplexControl a0, const ::QStyleOptionComplex*a1, ::QPainter*a2, const ::QWidget*a3) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[20]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_drawComplexControl);

    if (!sipMeth)
    {
        ::CalibreStyle::drawComplexControl(a0, a1, a2, a3);
        return;
    }

    extern void sipVH_progress_indicator_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QStyle::ComplexControl, const ::QStyleOptionComplex*, ::QPainter*, const ::QWidget*);

    sipVH_progress_indicator_9(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

::QStyle::SubControl sipCalibreStyle::hitTestComplexControl(::QStyle::ComplexControl a0, const ::QStyleOptionComplex*a1, const ::QPoint& a2, const ::QWidget*a3) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[21]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_hitTestComplexControl);

    if (!sipMeth)
        return ::CalibreStyle::hitTestComplexControl(a0, a1, a2, a3);

    extern ::QStyle::SubControl sipVH_progress_indicator_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QStyle::ComplexControl, const ::QStyleOptionComplex*, const ::QPoint&, const ::QWidget*);

    return sipVH_progress_indicator_8(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

::QRect sipCalibreStyle::subControlRect(::QStyle::ComplexControl a0, const ::QStyleOptionComplex*a1, ::QStyle::SubControl a2, const ::QWidget*a3) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[22]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_subControlRect);

    if (!sipMeth)
        return ::CalibreStyle::subControlRect(a0, a1, a2, a3);

    extern ::QRect sipVH_progress_indicator_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QStyle::ComplexControl, const ::QStyleOptionComplex*, ::QStyle::SubControl, const ::QWidget*);

    return sipVH_progress_indicator_7(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

int sipCalibreStyle::pixelMetric(::QStyle::PixelMetric a0, const ::QStyleOption*a1, const ::QWidget*a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[23]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_pixelMetric);

    if (!sipMeth)
        return ::CalibreStyle::pixelMetric(a0, a1, a2);

    extern int sipVH_progress_indicator_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QStyle::PixelMetric, const ::QStyleOption*, const ::QWidget*);

    return sipVH_progress_indicator_6(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

::QSize sipCalibreStyle::sizeFromContents(::QStyle::ContentsType a0, const ::QStyleOption*a1, const ::QSize& a2, const ::QWidget*a3) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[24]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sizeFromContents);

    if (!sipMeth)
        return ::CalibreStyle::sizeFromContents(a0, a1, a2, a3);

    extern ::QSize sipVH_progress_indicator_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QStyle::ContentsType, const ::QStyleOption*, const ::QSize&, const ::QWidget*);

    return sipVH_progress_indicator_5(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

int sipCalibreStyle::styleHint(::QStyle::StyleHint a0, const ::QStyleOption*a1, const ::QWidget*a2, ::QStyleHintReturn*a3) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[25]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_styleHint);

    if (!sipMeth)
        return ::CalibreStyle::styleHint(a0, a1, a2, a3);

    extern int sipVH_progress_indicator_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QStyle::StyleHint, const ::QStyleOption*, const ::QWidget*, ::QStyleHintReturn*);

    return sipVH_progress_indicator_4(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

::QPixmap sipCalibreStyle::standardPixmap(::QStyle::StandardPixmap a0, const ::QStyleOption*a1, const ::QWidget*a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[26]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_standardPixmap);

    if (!sipMeth)
        return ::CalibreStyle::standardPixmap(a0, a1, a2);

    extern ::QPixmap sipVH_progress_indicator_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QStyle::StandardPixmap, const ::QStyleOption*, const ::QWidget*);

    return sipVH_progress_indicator_3(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

::QIcon sipCalibreStyle::standardIcon(::QStyle::StandardPixmap a0, const ::QStyleOption*a1, const ::QWidget*a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[27]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_standardIcon);

    if (!sipMeth)
        return ::CalibreStyle::standardIcon(a0, a1, a2);

    extern ::QIcon sipVH_progress_indicator_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QStyle::StandardPixmap, const ::QStyleOption*, const ::QWidget*);

    return sipVH_progress_indicator_2(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

::QPixmap sipCalibreStyle::generatedIconPixmap(::QIcon::Mode a0, const ::QPixmap& a1, const ::QStyleOption*a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[28]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_generatedIconPixmap);

    if (!sipMeth)
        return ::CalibreStyle::generatedIconPixmap(a0, a1, a2);

    extern ::QPixmap sipVH_progress_indicator_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QIcon::Mode, const ::QPixmap&, const ::QStyleOption*);

    return sipVH_progress_indicator_1(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

int sipCalibreStyle::layoutSpacing(::QSizePolicy::ControlType a0, ::QSizePolicy::ControlType a1, ::Qt::Orientation a2, const ::QStyleOption*a3, const ::QWidget*a4) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[29]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_layoutSpacing);

    if (!sipMeth)
        return ::CalibreStyle::layoutSpacing(a0, a1, a2, a3, a4);

    extern int sipVH_progress_indicator_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QSizePolicy::ControlType, ::QSizePolicy::ControlType, ::Qt::Orientation, const ::QStyleOption*, const ::QWidget*);

    return sipVH_progress_indicator_0(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3, a4);
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_CalibreStyle(void *, const sipTypeDef *);}
static void *cast_CalibreStyle(void *sipCppV, const sipTypeDef *targetType)
{
    ::CalibreStyle *sipCpp = reinterpret_cast< ::CalibreStyle *>(sipCppV);

    if (targetType == sipType_CalibreStyle)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QProxyStyle)->ctd_cast(static_cast< ::QProxyStyle *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_CalibreStyle(void *, int);}
static void release_CalibreStyle(void *sipCppV, int)
{
    ::CalibreStyle *sipCpp = reinterpret_cast< ::CalibreStyle *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_CalibreStyle(sipSimpleWrapper *);}
static void dealloc_CalibreStyle(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipCalibreStyle *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_CalibreStyle(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_CalibreStyle(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_CalibreStyle(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipCalibreStyle *sipCpp = SIP_NULLPTR;

    {
        int a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "i", &a0))
        {
            sipCpp = new sipCalibreStyle(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_CalibreStyle[] = {{3, 2, 1}};

PyDoc_STRVAR(doc_CalibreStyle, "\1CalibreStyle(transient_scroller: int)");


static pyqt6ClassPluginDef plugin_CalibreStyle = {
    &::CalibreStyle::staticMetaObject,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_progress_indicator_CalibreStyle = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_CLASS,
        sipNameNr_CalibreStyle,
        SIP_NULLPTR,
        &plugin_CalibreStyle,
    },
    {
        sipNameNr_CalibreStyle,
        {0, 0, 1},
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_CalibreStyle,
    -1,
    -1,
    supers_CalibreStyle,
    SIP_NULLPTR,
    init_type_CalibreStyle,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_CalibreStyle,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_CalibreStyle,
    cast_CalibreStyle,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::CalibreStyle),
};
