/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 */

#ifndef _rcc_backendAPI_H
#define _rcc_backendAPI_H

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Vulkan
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL_ES2
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_RCCResourceLibrary__CompressionAlgorithm 0
#define sipName_RCCResourceLibrary__CompressionAlgorithm &sipStrings_rcc_backend[0]
#define sipNameNr_RCCResourceLibrary__Format 41
#define sipName_RCCResourceLibrary__Format &sipStrings_rcc_backend[41]
#define sipNameNr_setCompressionAlgorithm 68
#define sipName_setCompressionAlgorithm &sipStrings_rcc_backend[68]
#define sipNameNr_CompressionAlgorithm 20
#define sipName_CompressionAlgorithm &sipStrings_rcc_backend[20]
#define sipNameNr_compressionAlgorithm 92
#define sipName_compressionAlgorithm &sipStrings_rcc_backend[92]
#define sipNameNr_RCCResourceLibrary 113
#define sipName_RCCResourceLibrary &sipStrings_rcc_backend[113]
#define sipNameNr_failedResources 132
#define sipName_failedResources &sipStrings_rcc_backend[132]
#define sipNameNr_setResourceRoot 148
#define sipName_setResourceRoot &sipStrings_rcc_backend[148]
#define sipNameNr_setUseNameSpace 164
#define sipName_setUseNameSpace &sipStrings_rcc_backend[164]
#define sipNameNr_formatVersion 180
#define sipName_formatVersion &sipStrings_rcc_backend[180]
#define sipNameNr_setInputFiles 194
#define sipName_setInputFiles &sipStrings_rcc_backend[194]
#define sipNameNr_setOutputName 208
#define sipName_setOutputName &sipStrings_rcc_backend[208]
#define sipNameNr_resourceRoot 222
#define sipName_resourceRoot &sipStrings_rcc_backend[222]
#define sipNameNr_useNameSpace 235
#define sipName_useNameSpace &sipStrings_rcc_backend[235]
#define sipNameNr_Python_Code 248
#define sipName_Python_Code &sipStrings_rcc_backend[248]
#define sipNameNr_rcc_backend 260
#define sipName_rcc_backend &sipStrings_rcc_backend[260]
#define sipNameNr_setInitName 272
#define sipName_setInitName &sipStrings_rcc_backend[272]
#define sipNameNr_outputName 284
#define sipName_outputName &sipStrings_rcc_backend[284]
#define sipNameNr_setVerbose 295
#define sipName_setVerbose &sipStrings_rcc_backend[295]
#define sipNameNr_dataFiles 306
#define sipName_dataFiles &sipStrings_rcc_backend[306]
#define sipNameNr_readFiles 316
#define sipName_readFiles &sipStrings_rcc_backend[316]
#define sipNameNr_setFormat 326
#define sipName_setFormat &sipStrings_rcc_backend[326]
#define sipNameNr_setNoZstd 336
#define sipName_setNoZstd &sipStrings_rcc_backend[336]
#define sipNameNr_initName 346
#define sipName_initName &sipStrings_rcc_backend[346]
#define sipNameNr_verbose 355
#define sipName_verbose &sipStrings_rcc_backend[355]
#define sipNameNr_Binary 363
#define sipName_Binary &sipStrings_rcc_backend[363]
#define sipNameNr_C_Code 370
#define sipName_C_Code &sipStrings_rcc_backend[370]
#define sipNameNr_Format 61
#define sipName_Format &sipStrings_rcc_backend[61]
#define sipNameNr_format 377
#define sipName_format &sipStrings_rcc_backend[377]
#define sipNameNr_noZstd 384
#define sipName_noZstd &sipStrings_rcc_backend[384]
#define sipNameNr_output 391
#define sipName_output &sipStrings_rcc_backend[391]
#define sipNameNr_None_ 398
#define sipName_None_ &sipStrings_rcc_backend[398]
#define sipNameNr_Pass1 404
#define sipName_Pass1 &sipStrings_rcc_backend[404]
#define sipNameNr_Pass2 410
#define sipName_Pass2 &sipStrings_rcc_backend[410]
#define sipNameNr_Best 416
#define sipName_Best &sipStrings_rcc_backend[416]
#define sipNameNr_Zlib 421
#define sipName_Zlib &sipStrings_rcc_backend[421]
#define sipNameNr_Zstd 341
#define sipName_Zstd &sipStrings_rcc_backend[341]

#define sipMalloc                   sipAPI_rcc_backend->api_malloc
#define sipFree                     sipAPI_rcc_backend->api_free
#define sipBuildResult              sipAPI_rcc_backend->api_build_result
#define sipCallMethod               sipAPI_rcc_backend->api_call_method
#define sipCallProcedureMethod      sipAPI_rcc_backend->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_rcc_backend->api_call_error_handler
#define sipParseResultEx            sipAPI_rcc_backend->api_parse_result_ex
#define sipParseResult              sipAPI_rcc_backend->api_parse_result
#define sipParseArgs                sipAPI_rcc_backend->api_parse_args
#define sipParseKwdArgs             sipAPI_rcc_backend->api_parse_kwd_args
#define sipParsePair                sipAPI_rcc_backend->api_parse_pair
#define sipInstanceDestroyed        sipAPI_rcc_backend->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_rcc_backend->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_rcc_backend->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_rcc_backend->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_rcc_backend->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_rcc_backend->api_convert_to_void_ptr
#define sipAddException             sipAPI_rcc_backend->api_add_exception
#define sipNoFunction               sipAPI_rcc_backend->api_no_function
#define sipNoMethod                 sipAPI_rcc_backend->api_no_method
#define sipAbstractMethod           sipAPI_rcc_backend->api_abstract_method
#define sipBadClass                 sipAPI_rcc_backend->api_bad_class
#define sipBadCatcherResult         sipAPI_rcc_backend->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_rcc_backend->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_rcc_backend->api_bad_operator_arg
#define sipTrace                    sipAPI_rcc_backend->api_trace
#define sipTransferBack             sipAPI_rcc_backend->api_transfer_back
#define sipTransferTo               sipAPI_rcc_backend->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_rcc_backend->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_rcc_backend->api_wrapper_type
#define sipWrapperType_Type         sipAPI_rcc_backend->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_rcc_backend->api_voidptr_type
#define sipGetPyObject              sipAPI_rcc_backend->api_get_pyobject
#define sipGetAddress               sipAPI_rcc_backend->api_get_address
#define sipGetMixinAddress          sipAPI_rcc_backend->api_get_mixin_address
#define sipGetCppPtr                sipAPI_rcc_backend->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_rcc_backend->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_rcc_backend->api_call_hook
#define sipEndThread                sipAPI_rcc_backend->api_end_thread
#define sipRaiseUnknownException    sipAPI_rcc_backend->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_rcc_backend->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_rcc_backend->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_rcc_backend->api_add_type_instance
#define sipPySlotExtend             sipAPI_rcc_backend->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_rcc_backend->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_rcc_backend->api_can_convert_to_type
#define sipConvertToType            sipAPI_rcc_backend->api_convert_to_type
#define sipForceConvertToType       sipAPI_rcc_backend->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_rcc_backend->api_convert_to_enum
#define sipConvertToBool            sipAPI_rcc_backend->api_convert_to_bool
#define sipReleaseType              sipAPI_rcc_backend->api_release_type
#define sipConvertFromType          sipAPI_rcc_backend->api_convert_from_type
#define sipConvertFromNewType       sipAPI_rcc_backend->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_rcc_backend->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_rcc_backend->api_convert_from_enum
#define sipGetState                 sipAPI_rcc_backend->api_get_state
#define sipExportSymbol             sipAPI_rcc_backend->api_export_symbol
#define sipImportSymbol             sipAPI_rcc_backend->api_import_symbol
#define sipFindType                 sipAPI_rcc_backend->api_find_type
#define sipBytes_AsChar             sipAPI_rcc_backend->api_bytes_as_char
#define sipBytes_AsString           sipAPI_rcc_backend->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_rcc_backend->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_rcc_backend->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_rcc_backend->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_rcc_backend->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_rcc_backend->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_rcc_backend->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_rcc_backend->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_rcc_backend->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_rcc_backend->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_rcc_backend->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_rcc_backend->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_rcc_backend->api_get_reference
#define sipKeepReference            sipAPI_rcc_backend->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_rcc_backend->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_rcc_backend->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_rcc_backend->api_type_from_py_type_object
#define sipTypeScope                sipAPI_rcc_backend->api_type_scope
#define sipResolveTypedef           sipAPI_rcc_backend->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_rcc_backend->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_rcc_backend->api_enable_autoconversion
#define sipInitMixin                sipAPI_rcc_backend->api_init_mixin
#define sipExportModule             sipAPI_rcc_backend->api_export_module
#define sipInitModule               sipAPI_rcc_backend->api_init_module
#define sipGetInterpreter           sipAPI_rcc_backend->api_get_interpreter
#define sipSetTypeUserData          sipAPI_rcc_backend->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_rcc_backend->api_get_type_user_data
#define sipPyTypeDict               sipAPI_rcc_backend->api_py_type_dict
#define sipPyTypeName               sipAPI_rcc_backend->api_py_type_name
#define sipGetCFunction             sipAPI_rcc_backend->api_get_c_function
#define sipGetMethod                sipAPI_rcc_backend->api_get_method
#define sipFromMethod               sipAPI_rcc_backend->api_from_method
#define sipGetDate                  sipAPI_rcc_backend->api_get_date
#define sipFromDate                 sipAPI_rcc_backend->api_from_date
#define sipGetDateTime              sipAPI_rcc_backend->api_get_datetime
#define sipFromDateTime             sipAPI_rcc_backend->api_from_datetime
#define sipGetTime                  sipAPI_rcc_backend->api_get_time
#define sipFromTime                 sipAPI_rcc_backend->api_from_time
#define sipIsUserType               sipAPI_rcc_backend->api_is_user_type
#define sipCheckPluginForType       sipAPI_rcc_backend->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_rcc_backend->api_unicode_new
#define sipUnicodeWrite             sipAPI_rcc_backend->api_unicode_write
#define sipUnicodeData              sipAPI_rcc_backend->api_unicode_data
#define sipGetBufferInfo            sipAPI_rcc_backend->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_rcc_backend->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_rcc_backend->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_rcc_backend->api_is_derived_class
#define sipGetUserObject            sipAPI_rcc_backend->api_get_user_object
#define sipSetUserObject            sipAPI_rcc_backend->api_set_user_object
#define sipRegisterEventHandler     sipAPI_rcc_backend->api_register_event_handler
#define sipConvertToArray           sipAPI_rcc_backend->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_rcc_backend->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_rcc_backend->api_enable_gc
#define sipPrintObject              sipAPI_rcc_backend->api_print_object
#define sipLong_AsChar              sipAPI_rcc_backend->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_rcc_backend->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_rcc_backend->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_rcc_backend->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_rcc_backend->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_rcc_backend->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_rcc_backend->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_rcc_backend->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_rcc_backend->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_rcc_backend->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_rcc_backend->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_rcc_backend->api_long_as_size_t
#define sipVisitWrappers            sipAPI_rcc_backend->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_rcc_backend->api_register_exit_notifier
#define sipDeprecated               sipAPI_rcc_backend->api_deprecated
#define sipPyTypeDictRef            sipAPI_rcc_backend->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_rcc_backend->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_rcc_backend->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_rcc_backend->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_rcc_backend->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_rcc_backend->api_release_type_us
#define sipIsPyMethod               sipAPI_rcc_backend->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_rcc_backend[];

#define sipType_RCCResourceLibrary sipExportedTypes_rcc_backend[0]

#define sipType_RCCResourceLibrary_CompressionAlgorithm sipExportedTypes_rcc_backend[1]

#define sipType_RCCResourceLibrary_Format sipExportedTypes_rcc_backend[2]

extern sipClassTypeDef sipTypeDef_rcc_backend_RCCResourceLibrary;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_rcc_backend;
extern sipExportedModuleDef sipModuleAPI_rcc_backend;
extern sipTypeDef *sipExportedTypes_rcc_backend[];

#define sipType_QIODevice sipImportedTypes_rcc_backend_QtCore[0].it_td

#define sipType_QStringList sipImportedTypes_rcc_backend_QtCore[2].it_td

#define sipType_QString sipImportedTypes_rcc_backend_QtCore[1].it_td
extern sipImportedTypeDef sipImportedTypes_rcc_backend_QtCore[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_rcc_backend_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_rcc_backend_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_rcc_backend_qt_metacast;

#endif
