/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 */

#include "sipAPIprogress_indicator.h"

#line 27 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/QProgressIndicator.sip"
#include <QProgressIndicator.h>
#line 12 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorSpinAnimator.cpp"

#line 28 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 16 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorSpinAnimator.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qpainter.sip"
#include <qpainter.h>
#line 19 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorSpinAnimator.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qrect.sip"
#include <qrect.h>
#line 22 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorSpinAnimator.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qcolor.sip"
#include <qcolor.h>
#line 25 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorSpinAnimator.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 30 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorSpinAnimator.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 33 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorSpinAnimator.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 36 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorSpinAnimator.cpp"
#line 277 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 39 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorSpinAnimator.cpp"
#line 254 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 42 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorSpinAnimator.cpp"
#line 24 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 45 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorSpinAnimator.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 48 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorSpinAnimator.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 51 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorSpinAnimator.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 54 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorSpinAnimator.cpp"
#line 135 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 57 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorSpinAnimator.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 62 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorSpinAnimator.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 65 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorSpinAnimator.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 68 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorSpinAnimator.cpp"
#line 25 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qflags.sip"
#include <qglobal.h>
#line 71 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorSpinAnimator.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 74 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorSpinAnimator.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 77 "/build/calibre/src/calibre-9.11.0/build/pyqt/progress_indicator/build/progress_indicator/sipprogress_indicatorSpinAnimator.cpp"


class sipSpinAnimator : public ::SpinAnimator
{
public:
    sipSpinAnimator(::QObject*, int);
    virtual ~sipSpinAnimator();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipSpinAnimator(const sipSpinAnimator &);
    sipSpinAnimator &operator = (const sipSpinAnimator &);

    char sipPyMethods[7];
};

sipSpinAnimator::sipSpinAnimator(::QObject*a0, int a1): ::SpinAnimator(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipSpinAnimator::~sipSpinAnimator()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipSpinAnimator::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_progress_indicator_qt_metaobject(sipPySelf, sipType_SpinAnimator);

    return ::SpinAnimator::metaObject();
}

int sipSpinAnimator::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::SpinAnimator::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_progress_indicator_qt_metacall(sipPySelf, sipType_SpinAnimator, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipSpinAnimator::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_progress_indicator_qt_metacast(sipPySelf, sipType_SpinAnimator, _clname, &sipCpp) ? sipCpp : ::SpinAnimator::qt_metacast(_clname));
}

bool sipSpinAnimator::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::SpinAnimator::event(a0);

    extern bool sipVH_progress_indicator_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_progress_indicator_21(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipSpinAnimator::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::SpinAnimator::eventFilter(a0, a1);

    extern bool sipVH_progress_indicator_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_progress_indicator_22(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipSpinAnimator::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::SpinAnimator::timerEvent(a0);
        return;
    }

    extern void sipVH_progress_indicator_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_progress_indicator_23(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipSpinAnimator::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::SpinAnimator::childEvent(a0);
        return;
    }

    extern void sipVH_progress_indicator_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_progress_indicator_24(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipSpinAnimator::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::SpinAnimator::customEvent(a0);
        return;
    }

    extern void sipVH_progress_indicator_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_progress_indicator_25(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipSpinAnimator::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::SpinAnimator::connectNotify(a0);
        return;
    }

    extern void sipVH_progress_indicator_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_progress_indicator_26(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipSpinAnimator::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::SpinAnimator::disconnectNotify(a0);
        return;
    }

    extern void sipVH_progress_indicator_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_progress_indicator_26(sipGILState, sipImportedVirtErrorHandlers_progress_indicator_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_SpinAnimator_get_arc_length, "get_arc_length(self) -> float");

extern "C" {static PyObject *meth_SpinAnimator_get_arc_length(PyObject *, PyObject *);}
static PyObject *meth_SpinAnimator_get_arc_length(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::SpinAnimator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_SpinAnimator, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->get_arc_length();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_SpinAnimator, sipName_get_arc_length, doc_SpinAnimator_get_arc_length);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_SpinAnimator_get_arc_rotation, "get_arc_rotation(self) -> int");

extern "C" {static PyObject *meth_SpinAnimator_get_arc_rotation(PyObject *, PyObject *);}
static PyObject *meth_SpinAnimator_get_arc_rotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::SpinAnimator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_SpinAnimator, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->get_arc_rotation();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_SpinAnimator, sipName_get_arc_rotation, doc_SpinAnimator_get_arc_rotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_SpinAnimator_get_overall_rotation, "get_overall_rotation(self) -> int");

extern "C" {static PyObject *meth_SpinAnimator_get_overall_rotation(PyObject *, PyObject *);}
static PyObject *meth_SpinAnimator_get_overall_rotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::SpinAnimator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_SpinAnimator, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->get_overall_rotation();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_SpinAnimator, sipName_get_overall_rotation, doc_SpinAnimator_get_overall_rotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_SpinAnimator_draw, "draw(self, painter: QPainter, bounds: QRect, color: QColor|Qt.GlobalColor|int, thickness: float = 0)");

extern "C" {static PyObject *meth_SpinAnimator_draw(PyObject *, PyObject *);}
static PyObject *meth_SpinAnimator_draw(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPainter* a0;
        ::QRect* a1;
        const ::QColor* a2;
        int a2State = 0;
        float a3 = 0;
        ::SpinAnimator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J9J1|f", &sipSelf, sipType_SpinAnimator, &sipCpp, sipType_QPainter, &a0, sipType_QRect, &a1, sipType_QColor, &a2, &a2State, &a3))
        {
            sipCpp->draw(*a0, *a1, *a2, a3);
            sipReleaseType(const_cast< ::QColor *>(a2), sipType_QColor, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_SpinAnimator, sipName_draw, doc_SpinAnimator_draw);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_SpinAnimator_start, "start(self)");

extern "C" {static PyObject *meth_SpinAnimator_start(PyObject *, PyObject *);}
static PyObject *meth_SpinAnimator_start(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::SpinAnimator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_SpinAnimator, &sipCpp))
        {
            sipCpp->start();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_SpinAnimator, sipName_start, doc_SpinAnimator_start);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_SpinAnimator_stop, "stop(self)");

extern "C" {static PyObject *meth_SpinAnimator_stop(PyObject *, PyObject *);}
static PyObject *meth_SpinAnimator_stop(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::SpinAnimator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_SpinAnimator, &sipCpp))
        {
            sipCpp->stop();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_SpinAnimator, sipName_stop, doc_SpinAnimator_stop);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_SpinAnimator_is_running, "is_running(self) -> bool");

extern "C" {static PyObject *meth_SpinAnimator_is_running(PyObject *, PyObject *);}
static PyObject *meth_SpinAnimator_is_running(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::SpinAnimator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_SpinAnimator, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->is_running();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_SpinAnimator, sipName_is_running, doc_SpinAnimator_is_running);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_SpinAnimator_set_arc_length, "set_arc_length(self, val: float)");

extern "C" {static PyObject *meth_SpinAnimator_set_arc_length(PyObject *, PyObject *);}
static PyObject *meth_SpinAnimator_set_arc_length(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::SpinAnimator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_SpinAnimator, &sipCpp, &a0))
        {
            sipCpp->set_arc_length(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_SpinAnimator, sipName_set_arc_length, doc_SpinAnimator_set_arc_length);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_SpinAnimator_set_arc_rotation, "set_arc_rotation(self, val: int)");

extern "C" {static PyObject *meth_SpinAnimator_set_arc_rotation(PyObject *, PyObject *);}
static PyObject *meth_SpinAnimator_set_arc_rotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::SpinAnimator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_SpinAnimator, &sipCpp, &a0))
        {
            sipCpp->set_arc_rotation(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_SpinAnimator, sipName_set_arc_rotation, doc_SpinAnimator_set_arc_rotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_SpinAnimator_set_overall_rotation, "set_overall_rotation(self, val: int)");

extern "C" {static PyObject *meth_SpinAnimator_set_overall_rotation(PyObject *, PyObject *);}
static PyObject *meth_SpinAnimator_set_overall_rotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::SpinAnimator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_SpinAnimator, &sipCpp, &a0))
        {
            sipCpp->set_overall_rotation(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_SpinAnimator, sipName_set_overall_rotation, doc_SpinAnimator_set_overall_rotation);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_SpinAnimator(void *, const sipTypeDef *);}
static void *cast_SpinAnimator(void *sipCppV, const sipTypeDef *targetType)
{
    ::SpinAnimator *sipCpp = reinterpret_cast< ::SpinAnimator *>(sipCppV);

    if (targetType == sipType_SpinAnimator)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_SpinAnimator(void *, int);}
static void release_SpinAnimator(void *sipCppV, int)
{
    ::SpinAnimator *sipCpp = reinterpret_cast< ::SpinAnimator *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_SpinAnimator(Py_ssize_t);}
static void *array_SpinAnimator(Py_ssize_t sipNrElem)
{
    return new ::SpinAnimator[sipNrElem];
}


extern "C" {static void array_delete_SpinAnimator(void *);}
static void array_delete_SpinAnimator(void *sipCpp)
{
    delete[] reinterpret_cast< ::SpinAnimator *>(sipCpp);
}


extern "C" {static void dealloc_SpinAnimator(sipSimpleWrapper *);}
static void dealloc_SpinAnimator(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipSpinAnimator *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_SpinAnimator(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_SpinAnimator(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_SpinAnimator(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipSpinAnimator *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;
        int a1 = 300;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "|JHi", sipType_QObject, &a0, sipOwner, &a1))
        {
            sipCpp = new sipSpinAnimator(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_SpinAnimator[] = {{4, 0, 1}};


static PyMethodDef methods_SpinAnimator[] = {
    {sipName_draw, meth_SpinAnimator_draw, METH_VARARGS, doc_SpinAnimator_draw},
    {sipName_get_arc_length, meth_SpinAnimator_get_arc_length, METH_VARARGS, doc_SpinAnimator_get_arc_length},
    {sipName_get_arc_rotation, meth_SpinAnimator_get_arc_rotation, METH_VARARGS, doc_SpinAnimator_get_arc_rotation},
    {sipName_get_overall_rotation, meth_SpinAnimator_get_overall_rotation, METH_VARARGS, doc_SpinAnimator_get_overall_rotation},
    {sipName_is_running, meth_SpinAnimator_is_running, METH_VARARGS, doc_SpinAnimator_is_running},
    {sipName_set_arc_length, meth_SpinAnimator_set_arc_length, METH_VARARGS, doc_SpinAnimator_set_arc_length},
    {sipName_set_arc_rotation, meth_SpinAnimator_set_arc_rotation, METH_VARARGS, doc_SpinAnimator_set_arc_rotation},
    {sipName_set_overall_rotation, meth_SpinAnimator_set_overall_rotation, METH_VARARGS, doc_SpinAnimator_set_overall_rotation},
    {sipName_start, meth_SpinAnimator_start, METH_VARARGS, doc_SpinAnimator_start},
    {sipName_stop, meth_SpinAnimator_stop, METH_VARARGS, doc_SpinAnimator_stop}
};

PyDoc_STRVAR(doc_SpinAnimator, "\1SpinAnimator(parent: QObject|None = None, speed_factor: int = 300)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_SpinAnimator[] = {
    {"updated()", "\1updated(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_SpinAnimator = {
    &::SpinAnimator::staticMetaObject,
    signals_SpinAnimator,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_progress_indicator_SpinAnimator = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_CLASS,
        sipNameNr_SpinAnimator,
        SIP_NULLPTR,
        &plugin_SpinAnimator,
    },
    {
        sipNameNr_SpinAnimator,
        {0, 0, 1},
        10, methods_SpinAnimator,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_SpinAnimator,
    -1,
    -1,
    supers_SpinAnimator,
    SIP_NULLPTR,
    init_type_SpinAnimator,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_SpinAnimator,
    SIP_NULLPTR,
    array_SpinAnimator,
    SIP_NULLPTR,
    release_SpinAnimator,
    cast_SpinAnimator,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_SpinAnimator,
    sizeof (::SpinAnimator),
};
